rp_binary_end

Macro rp_binary_end 

macro_rules! rp_binary_end {
    ($ptr:ident) => { ... };
}
Generate a static item containing the binary end address, and return its EntryAddr. The argument should be a symbol provided by the linker script that is located at the end of the binary.