macro_rules! pointer { ($tag:expr, $id:expr, $ptr:expr) => { ... }; }
Generate a static item containing the given pointer, and return its EntryAddr.
EntryAddr
You must pass a numeric tag, a numeric ID, and a pointer