pub struct PointerEntry { /* private fields */ }Expand description
An alias for IntegerEntry, taking a pointer instead of an integer
Implementations
Sourceimpl PointerEntry
impl PointerEntry
Sourcepub const fn new(tag: u16, id: u32, value: *const ()) -> PointerEntry
pub const fn new(tag: u16, id: u32, value: *const ()) -> PointerEntry
Create a new PointerEntry
Pointers will be marked as 32-bit integers in the binary information structure, as there is no separate data type tag for pointers. This assumes that pointers are 32 bit wide, which is obviously true for rp2040/rp2350. On 64 bit architectures, it will create a binary structure that likely can’t be parsed by picotool.